// -----------------------------------------------------------------------
// Copyright (C) 2019-2023, EyeLogic GmbH
//
// Permission is hereby granted, free of charge, to any person or
// organization obtaining a copy of the software and accompanying
// documentation covered by this license (the "Software") to use,
// reproduce, display, distribute, execute, and transmit the Software,
// and to prepare derivative works of the Software, and to permit
// third-parties to whom the Software is furnished to do so.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
// NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR ANYONE
// DISTRIBUTING THE SOFTWARE BE LIABLE FOR ANY DAMAGES OR OTHER
// LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT
// OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
// -----------------------------------------------------------------------

/**
 * @file ELCGazeSample.h
 *
 * @brief The file specifies the C container for a gaze sample.
 */

#pragma once

#include "ELCExports.hpp"

#include <stdint.h>

#ifdef _WIN32
#define STDCALL __stdcall
#else
#define STDCALL
#endif

#ifdef __cplusplus
#define EXTERNC extern "C"
#else
#define EXTERNC
#endif

/** @brief width of the image in pixels */
static const int32_t EYEIMAGE_WIDTH = 300;
/** @brief height of the image in pixels */
static const int32_t EYEIMAGE_HEIGHT = 90;

/**
 * @brief contains an image of the eyes captured by the device
 */
EXTERNC struct ELCEyeImage {
    /** @brief image buffer, stores all pixels as RGB value (3 bytes per pixel) */
    uint8_t data[ 300 * 90 * 3 ];
};
