﻿// -----------------------------------------------------------------------
// Copyright (C) 2019-2023, EyeLogic GmbH
//
// Permission is hereby granted, free of charge, to any person or
// organization obtaining a copy of the software and accompanying
// documentation covered by this license (the "Software") to use,
// reproduce, display, distribute, execute, and transmit the Software,
// and to prepare derivative works of the Software, and to permit
// third-parties to whom the Software is furnished to do so.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
// NON-INFRINGEMENT. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR ANYONE
// DISTRIBUTING THE SOFTWARE BE LIABLE FOR ANY DAMAGES OR OTHER
// LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT
// OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
// -----------------------------------------------------------------------

using System.Drawing;
using System.Drawing.Imaging;
using System.IO;
using System.Threading;
using System.Windows;
using System.Windows.Media.Imaging;
using System.Windows.Threading;

public partial class MainWindow : Window
{
    public EyeImageDemoClient m_demoClient;
    private delegate void     MainWindowDelegate( );

    public MainWindow( )
    {
        InitializeComponent( );

        m_demoClient = new EyeImageDemoClient( );
        if ( !m_demoClient.start( this ) ) {
            System.Console.WriteLine( "press enter to quit" );
            System.Console.ReadLine( );
            System.Environment.Exit( 1 );
        }
    }

    private void
    Window_Loaded( object sender, RoutedEventArgs e )
    {
        new Thread( ( ) =>
                    {
                        Thread.CurrentThread.IsBackground = true;
                        System.Console.WriteLine( "wait 5s..." );
                        System.Threading.Thread.Sleep( 5000 );
                        m_demoClient.stop( );

                        if ( !Dispatcher.CheckAccess( ) ) {
                            Dispatcher.BeginInvoke(
                                System.Windows.Threading.DispatcherPriority.Normal,
                                (MainWindowDelegate)delegate( ) { Hide( ); } );
                        }

                        System.Console.WriteLine( "press enter to quit" );
                        System.Console.ReadLine( );
                        System.Environment.Exit( 0 );
                    } )
            .Start( );
    }

    /** EyeImage callback - this method is called for each new eye image */
    public void
    onEyeImage( Bitmap eyeImage )
    {
        if ( !Dispatcher.CheckAccess( ) ) {
            Dispatcher.BeginInvoke( System.Windows.Threading.DispatcherPriority.Normal,
                                    (MainWindowDelegate)delegate( ) {
                                        var bitmapImage = new BitmapImage( );
                                        using ( var memory = new MemoryStream( ) )
                                        {
                                            eyeImage.Save( memory, ImageFormat.Bmp );
                                            memory.Position = 0;

                                            bitmapImage.BeginInit( );
                                            bitmapImage.StreamSource = memory;
                                            bitmapImage.CacheOption  = BitmapCacheOption.OnLoad;
                                            bitmapImage.EndInit( );
                                            bitmapImage.Freeze( );
                                            EyeImageViewer.Source = bitmapImage;
                                        }
                                    } );
        } else {
        }
    }
}