﻿using System;
using System.Threading;
using eyelogic;

namespace democlientCs
{
    public class DemoClientCs
    {
        /** EyeLogic API object */
        private ELCsApi m_api;

        static void Main( string[ ] args )
        {
            DemoClientCs client = new DemoClientCs( );
            client.run( );
        }

        void
        run( )
        {
            try {
                // initialize API
                System.Console.WriteLine( "initialize EyeLogic API..." );
                m_api = new ELCsApi( "C# Client" );
                System.Console.WriteLine( "    ... done" );

                // connect to EyeLogic Server
                System.Console.WriteLine( "establish connection to server" );
                m_api.connect( );
                System.Console.WriteLine( "    ... done, connected" );

                // check if a device is connected
                ELCsApi.DeviceConfig deviceConfig = m_api.getDeviceConfig( );
                if ( deviceConfig == null ) {
                    System.Console.WriteLine( "no device connected - exiting" );
                    m_api.disconnect( );
                    m_api.destroy( );
                    System.Console.WriteLine( "press enter to quit" );
                    System.Console.ReadLine( );
                    return;
                }
                System.Console.WriteLine( "device found, serial: {0}",
                                          deviceConfig.formatDeviceSerial( ) );

                // check screen
                ELCsApi.ScreenConfig screenConfig = m_api.getActiveScreen( );
                if ( screenConfig == null ) {
                    System.Console.WriteLine( "no screen found - exiting" );
                    m_api.disconnect( );
                    m_api.destroy( );
                    System.Console.WriteLine( "press enter to quit" );
                    System.Console.ReadLine( );
                    return;
                }
                System.Console.WriteLine( "screen found, resolution: {0} x {1}",
                                          screenConfig.resolutionX,
                                          screenConfig.resolutionY );

                // start tracking
                System.Console.WriteLine( "start tracking with default framerate" );
                m_api.requestTracking( 0 );
                System.Console.WriteLine( "    ... done" );

                // perform calibration
                System.Console.WriteLine( "start default calibration" );
                m_api.calibrate( 0 );
                System.Console.WriteLine( "    ... success" );

                // perform calibration
                System.Console.WriteLine( "start validation" );
                ELCsApi.ValidationResult validationResult = m_api.validate( );
                System.Console.WriteLine( "    ... success:\n" );

                for ( int i = 0; i < 4; i++ ) {
                    string leftDeg, leftPx;
                    // degree and pixel deviations will always be either both valid or both invalid
                    if ( validationResult.pointsData[ i ].meanDeviationLeftDeg ==
                         ELCsApi.InvalidValue ) {
                        leftDeg = leftPx = "N/A";
                    } else {
                        leftDeg = String.Format(
                            "{0,4:F1} deg", validationResult.pointsData[ i ].meanDeviationLeftDeg );
                        leftPx = String.Format(
                            "{0,6:F1} px", validationResult.pointsData[ i ].meanDeviationLeftPx );
                    }

                    string rightDeg, rightPx;
                    // degree and pixel deviations will always be either both valid or both invalid
                    if ( validationResult.pointsData[ i ].meanDeviationRightDeg ==
                         ELCsApi.InvalidValue ) {
                        rightDeg = rightPx = "N/A";
                    } else {
                        rightDeg =
                            String.Format( "{0,4:F1} deg",
                                           validationResult.pointsData[ i ].meanDeviationRightDeg );
                        rightPx = String.Format(
                            "{0,6:F1} px", validationResult.pointsData[ i ].meanDeviationRightPx );
                    }

                    System.Console.WriteLine(
                        "{0}. point || position [px]: {1,4}, {2,4}  |  left: {3,9} / {4,9}  |  right: {5,9} / {6,9}",
                        i + 1,
                        validationResult.pointsData[ i ].validationPointPxX,
                        validationResult.pointsData[ i ].validationPointPxY,
                        leftDeg,
                        leftPx,
                        rightDeg,
                        rightPx );
                }

                // stop tracking
                System.Console.WriteLine( "stopping..." );
                m_api.unrequestTracking( );
                m_api.disconnect( );
                m_api.destroy( );
                System.Console.WriteLine( "    ... done" );
            } catch ( ELException e ) {
                System.Console.WriteLine( e.ToString( ) + " (error ID: " + e.Error + ")" );
                if ( m_api != null ) {
                    m_api.disconnect( );
                    m_api.destroy( );
                }
            }

            System.Console.WriteLine( "press enter to quit" );
            System.Console.ReadLine( );
        }
    }
}
